@@ -9,15 +9,16 @@
 
 #include "blinken.h"
 
-#include <qcursor.h>
-#include <qevent.h>
-#include <qpainter.h>
-#include <qsvgrenderer.h>
-#include <qtimer.h>
+#include <QCursor>
+#include <QEvent>
+#include <QPainter>
+#include <QSvgRenderer>
+#include <QTimer>
 #include <QAction>
 #include <QApplication>
 #include <QInputDialog>
 #include <QKeySequence>
+#include <QMouseEvent>
 
 #include <kconfig.h>
 #include <khelpmenu.h>
@@ -204,8 +205,8 @@ void blinken::paintEvent(QPaintEvent *)
 		p.setBrush(oBrush);
 		
 		// store the "real" rect
-		m_fontRect = p.worldMatrix().mapRect(m_fontRect);
-		m_soundRect = p.worldMatrix().mapRect(m_soundRect);
+		m_fontRect = p.worldTransform().mapRect(m_fontRect);
+		m_soundRect = p.worldTransform().mapRect(m_soundRect);
 	}
 	
 	drawScoreAndCounter(p);
@@ -842,7 +843,7 @@ void blinken::drawText(QPainter &p, const QString &text, const QPointF &center,
 	{
 		p.fillRect(r, m_fillColor);
 		p.setPen(QPen(Qt::black, 3));
-		p.drawRoundRect(r, 15, 15);
+		p.drawRoundedRect(r, 15, 15, Qt::RelativeSize);
 	}
 	
 	if (highlight)
@@ -855,7 +856,7 @@ void blinken::drawText(QPainter &p, const QString &text, const QPointF &center,
 	}
 	p.drawText(r, Qt::AlignCenter, text);
 	
-	if (rect) *rect = p.worldMatrix().mapRect(r);
+	if (rect) *rect = p.worldTransform().mapRect(r);
 	
 	p.setFont(oldFont);
 }
